;; Quail packages for IBM PC code pages [postfix edition]
;; Copyright (C) 1998 Free Software Foundation, Inc.

;; Keywords: multilingual, input method, pc

;; This file is part of GNU Emacs.

;; GNU Emacs is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; GNU Emacs is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with GNU Emacs; see the file COPYING.  If not, write to the
;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
;; Boston, MA 02111-1307, USA.

;; Author: Tim Van Holder <zastai@hotmail.com>
;; Credits:
;;  TAKAHASHI Naoto <ntakahas@etl.go.jp> for latin-post.el
;;  IBM for the 'Keyboards And Code Pages' booklet that came with IBM DOS 5.x
;;  recode 2.4.2

(require 'quail)

(quail-define-package
 "ibmpc-cp437-postfix" "IBM PC CodePage 437" "437>" t
 "Character input method with postfix modifiers for IBM PC codepage 437.
Note that this only a subset of the Latin-1 characterset is supported.

             | postfix | examples
 ------------+---------+----------
  acute      |    '    | a' -> ,A (B
  grave      |    `    | a` -> 
  circumflex |    ^    | a^ -> 
  diaeresis  |    \"    | a\" -> 
  tilde      |    ~    | n~ -> ,A$(B
  cedilla    |    ,    | c, -> 
  nordic     |    /    | a/ ->    e/ -> 
  others     |   /<>   | s/ -> ,Aa(B   ?/ -> ,A((B   !/ -> ,A-(B   << -> ,A.(B   >> -> ,A/(B

Doubling the postfix separates the letter and postfix: e.g. a'' -> a'
This codepage is used by the US keyboard and many European keyboards.
" nil t nil nil nil nil nil nil nil nil t)

(quail-define-rules
 ("!/" ?,A-(B)
 ("8/" ?,Al(B)
 ("<<" ?,A.(B)
 ("=/" ?,Aw(B)
 (">>" ?,A/(B)
 ("?/" ?,A((B)
 ("A/" ?)
 ("A\"" ?)
 ("C," ?)
 ("E'" ?)
 ("E/" ?)
 ("N~" ?,A%(B)
 ("O\"" ?)
 ("U\"" ?)
 ("a'" ?,A (B)
 ("a/" ?)
 ("a\"" ?)
 ("a^" ?)
 ("a`" ?)
 ("c," ?)
 ("e'" ?)
 ("e/" ?)
 ("e\"" ?)
 ("e^" ?)
 ("e`" ?)
 ("f/" ?)
 ("i'" ?,A!(B)
 ("i\"" ?)
 ("i^" ?)
 ("i`" ?)
 ("n~" ?,A$(B)
 ("o'" ?,A"(B)
 ("o\"" ?)
 ("o^" ?)
 ("o`" ?)
 ("s/" ?,Aa(B)
 ("u'" ?,A#(B)
 ("u\"" ?)
 ("u^" ?)
 ("u`" ?)
 ("v/" ?,A{(B)
 ("y\"" ?)

 ("!//" ["!/"])
 ("8//" ["8/"])
 ("<<<" ["<<"])
 ("=//" ["=/"])
 (">>>" [">>"])
 ("?//" ["?/"])
 ("A//" ["A/"])
 ("A\"\"" ["A\""])
 ("C,," ["C,"])
 ("E''" ["E'"])
 ("E//" ["E/"])
 ("N~~" ["N~"])
 ("O\"\"" ["O\""])
 ("U\"\"" ["U\""])
 ("a''" ["a'"])
 ("a//" ["a/"])
 ("a\"\"" ["a\""])
 ("a^^" ["a^"])
 ("a``" ["a`"])
 ("c,," ["c,"])
 ("e''" ["e'"])
 ("e//" ["e/"])
 ("e\"\"" ["e\""])
 ("e^^" ["e^"])
 ("e``" ["e`"])
 ("f//" ["8/"])
 ("i''" ["i'"])
 ("i\"\"" ["i\""])
 ("i^^" ["i^"])
 ("i``" ["i`"])
 ("n~~" ["n~"])
 ("o''" ["o'"])
 ("o\"\"" ["o\""])
 ("o^^" ["o^"])
 ("o``" ["o`"])
 ("s//" ["s/"])
 ("u''" ["u'"])
 ("u\"\"" ["u\""])
 ("u^^" ["u^"])
 ("u``" ["u`"])
 ("v//" ["8/"])
 ("y\"\"" ["y\""])
 )

(quail-define-package
 "ibmpc-cp850-postfix" "IBM PC CodePage 850" "850>" t
 "Character input method with postfix modifiers for IBM PC codepage 850

             | postfix | examples
 ------------+---------+----------
  acute      |    '    | a' -> ,A (B
  grave      |    `    | a` -> 
  circumflex |    ^    | a^ -> 
  diaeresis  |    \"    | a\" -> 
  tilde      |    ~    | a~ -> ,AF(B
  cedilla    |    ,    | c, -> 
  nordic     |    /    | d/ -> ,AP(B   t/ -> ,Ah(B   a/ ->    e/ ->    o/ -> 
  others     |   /<>   | s/ -> ,Aa(B   ?/ -> ,A((B   !/ -> ,A-(B   << -> ,A.(B   >> -> ,A/(B

Doubling the postfix separates the letter and postfix: e.g. a'' -> a'
This codepage is used by most European keyboards.
" nil t nil nil nil nil nil nil nil nil t)

(quail-define-rules
 ("!/" ?,A-(B)
 ("<<" ?,A.(B)
 (">>" ?,A/(B)
 ("?/" ?,A((B)
 ("A'" ?,A5(B)
 ("A/" ?)
 ("A\"" ?)
 ("A^" ?,A6(B)
 ("A`" ?,A7(B)
 ("A~" ?,AG(B)
 ("C," ?)
 ("D/" ?,AQ(B)
 ("E'" ?)
 ("E/" ?)
 ("E\"" ?,AS(B)
 ("E^" ?,AR(B)
 ("E`" ?,AT(B)
 ("I'" ?,AV(B)
 ("I\"" ?,AX(B)
 ("I^" ?,AW(B)
 ("I`" ?,A^(B)
 ("N~" ?,A%(B)
 ("O'" ?,A`(B)
 ("O/" ?)
 ("O\"" ?)
 ("O^" ?,Ab(B)
 ("O`" ?,Ac(B)
 ("O~" ?,Ae(B)
 ("T/" ?,Ag(B)
 ("U'" ?,Ai(B)
 ("U\"" ?)
 ("U^" ?,Aj(B)
 ("U`" ?,Ak(B)
 ("Y'" ?,Am(B)
 ("a'" ?,A (B)
 ("a/" ?)
 ("a\"" ?)
 ("a^" ?)
 ("a`" ?)
 ("a~" ?,AF(B)
 ("c," ?)
 ("c/" ?,A8(B)
 ("d/" ?,AP(B)
 ("e'" ?)
 ("e/" ?)
 ("e\"" ?)
 ("e^" ?)
 ("e`" ?)
 ("f/" ?)
 ("i'" ?,A!(B)
 ("i\"" ?)
 ("i^" ?)
 ("i`" ?)
 ("n~" ?,A$(B)
 ("o'" ?,A"(B)
 ("o/" ?)
 ("o\"" ?)
 ("o^" ?)
 ("o`" ?)
 ("o~" ?,Ad(B)
 ("r/" ?,A)(B)
 ("s/" ?,Aa(B)
 ("t/" ?,Ah(B)
 ("u'" ?,A#(B)
 ("u\"" ?)
 ("u^" ?)
 ("u`" ?)
 ("y'" ?,Al(B)
 ("y\"" ?)

 ("!//" ["!/"])
 ("<<<" ["<<"])
 (">>>" [">>"])
 ("?//" ["?/"])
 ("A''" ["A'"])
 ("A//" ["A/"])
 ("A\"\"" ["A\""])
 ("A^^" ["A^"])
 ("A``" ["A`"])
 ("A~~" ["A~"])
 ("C,," ["C,"])
 ("D//" ["D/"])
 ("E''" ["E'"])
 ("E//" ["E/"])
 ("E\"\"" ["E\""])
 ("E^^" ["E^"])
 ("E``" ["E`"])
 ("I''" ["I'"])
 ("I\"\"" ["I\""])
 ("I^^" ["I^"])
 ("I``" ["I`"])
 ("N~~" ["N~"])
 ("O''" ["O'"])
 ("O//" ["O/"])
 ("O\"\"" ["O\""])
 ("O^^" ["O^"])
 ("O``" ["O`"])
 ("O~~" ["O~"])
 ("T//" ["T/"])
 ("U''" ["U'"])
 ("U\"\"" ["U\""])
 ("U^^" ["U^"])
 ("U``" ["U`"])
 ("Y''" ["Y'"])
 ("a''" ["a'"])
 ("a//" ["a/"])
 ("a\"\"" ["a\""])
 ("a^^" ["a^"])
 ("a``" ["a`"])
 ("a~~" ["a~"])
 ("c,," ["c,"])
 ("c//" ["c/"])
 ("d//" ["d/"])
 ("e''" ["e'"])
 ("e//" ["e/"])
 ("e\"\"" ["e\""])
 ("e^^" ["e^"])
 ("e``" ["e`"])
 ("f//" ["f/"])
 ("i''" ["i'"])
 ("i\"\"" ["i\""])
 ("i^^" ["i^"])
 ("i``" ["i`"])
 ("n~~" ["n~"])
 ("o''" ["o'"])
 ("o//" ["o/"])
 ("o\"\"" ["o\""])
 ("o^^" ["o^"])
 ("o``" ["o`"])
 ("o~~" ["o~"])
 ("r//" ["r/"])
 ("s//" ["s/"])
 ("t//" ["t/"])
 ("u''" ["u'"])
 ("u\"\"" ["u\""])
 ("u^^" ["u^"])
 ("u``" ["u`"])
 ("y''" ["y'"])
 ("y\"\"" ["y\""])
 )

(quail-define-package
 "ibmpc-cp852-postfix" "IBM PC CodePage 852" "852>" t
 "Character input method with postfix modifiers for IBM PC codepage 852

             | postfix | examples
 ------------+---------+----------
  acute      |    '    | a' -> ,A (B
  dbl. acute |    :    | o: -> 
  circumflex |    ^    | a^ -> 
  caron      |    ~    | a~ -> ,AG(B
  diaeresis  |    \"    | a\" -> 
  cedilla    |    ,    | c, -> 
  ogonek     |    ,    | a, -> ,A%(B
  dot        |    .    | z. -> ,A>(B
  ring       |    .    | u. -> 
  stroke     |    /    | l/ ->    d/ -> ,AP(B
  others     |   /<>   | s/ -> ,Aa(B   << -> ,A.(B   >> -> ,A/(B

Doubling the postfix separates the letter and postfix: e.g. a'' -> a'
This codepage is used by Czech, Hungarian, Polish and Yugoslav keyboards.
" nil t nil nil nil nil nil nil nil nil t)

(quail-define-rules
 ("<<" ?,A.(B)
 (">>" ?,A/(B)
 ("A'" ?,A5(B)
 ("A," ?,A$(B)
 ("A\"" ?)
 ("A^" ?,A6(B)
 ("A~" ?,AF(B)
 ("C'" ?)
 ("C," ?)
 ("C~" ?,A,(B)
 ("D/" ?,AQ(B)
 ("D~" ?,AR(B)
 ("E'" ?)
 ("E," ?,A((B)
 ("E\"" ?,AS(B)
 ("E~" ?,A7(B)
 ("I'" ?,AV(B)
 ("I^" ?,AW(B)
 ("L'" ?)
 ("L/" ?)
 ("L~" ?)
 ("N'" ?,Ac(B)
 ("N~" ?,AU(B)
 ("O'" ?,A`(B)
 ("O:" ?)
 ("O\"" ?)
 ("O^" ?,Ab(B)
 ("R'" ?,Ah(B)
 ("R~" ?,A|(B)
 ("S'" ?)
 ("S," ?,A8(B)
 ("S~" ?,Af(B)
 ("T," ?,A](B)
 ("T~" ?)
 ("U'" ?,Ai(B)
 ("U." ?,A^(B)
 ("U:" ?,Ak(B)
 ("U\"" ?)
 ("Y'" ?,Am(B)
 ("Z'" ?)
 ("Z." ?,A=(B)
 ("Z~" ?,A&(B)
 ("a'" ?,A (B)
 ("a," ?,A%(B)
 ("a\"" ?)
 ("a^" ?)
 ("a~" ?,AG(B)
 ("c'" ?)
 ("c," ?)
 ("c~" ?)
 ("d/" ?,AP(B)
 ("d~" ?,AT(B)
 ("e'" ?)
 ("e," ?,A)(B)
 ("e\"" ?)
 ("e~" ?,AX(B)
 ("i'" ?,A!(B)
 ("i^" ?)
 ("l'" ?)
 ("l/" ?)
 ("l~" ?)
 ("n'" ?,Ad(B)
 ("n~" ?,Ae(B)
 ("o'" ?,A"(B)
 ("o:" ?)
 ("o\"" ?)
 ("o^" ?,Ab(B)
 ("r'" ?,Aj(B)
 ("r~" ?,A}(B)
 ("s'" ?)
 ("s," ?,A-(B)
 ("s/" ?,Aa(B)
 ("s~" ?,Ag(B)
 ("t," ?,An(B)
 ("t~" ?)
 ("u'" ?,A#(B)
 ("u." ?)
 ("u:" ?,A{(B)
 ("u\"" ?)
 ("y'" ?,Al(B)
 ("z'" ?,A+(B)
 ("z." ?,A>(B)
 ("z~" ?,A'(B)

 ("<<<" ["<<"])
 (">>>" [">>"])
 ("A''" ["A'"])
 ("A,," ["A,"])
 ("A\"\"" ["A\""])
 ("A^^" ["A^"])
 ("A~~" ["A~"])
 ("C''" ["C'"])
 ("C,," ["C,"])
 ("C~~" ["C~"])
 ("D//" ["D/"])
 ("D~~" ["D~"])
 ("E''" ["E'"])
 ("E,," ["E,"])
 ("E\"\"" ["E\""])
 ("E~~" ["E~"])
 ("I''" ["I'"])
 ("I^^" ["I^"])
 ("L''" ["L'"])
 ("L//" ["L/"])
 ("L~~" ["L~"])
 ("N''" ["N'"])
 ("N~~" ["N~"])
 ("O''" ["O'"])
 ("O::" ["O:"])
 ("O\"\"" ["O\""])
 ("O^^" ["O^"])
 ("R''" ["R'"])
 ("R~~" ["R~"])
 ("S''" ["S'"])
 ("S,," ["S,"])
 ("S~~" ["S~"])
 ("T,," ["T,"])
 ("T~~" ["T~"])
 ("U''" ["U'"])
 ("U.." ["U."])
 ("U::" ["U:"])
 ("U\"\"" ["U\""])
 ("Y''" ["Y'"])
 ("Z''" ["Z'"])
 ("Z.." ["Z."])
 ("Z~~" ["Z~"])
 ("a''" ["a'"])
 ("a,," ["a,"])
 ("a\"\"" ["a\""])
 ("a^^" ["a^"])
 ("a~~" ["a~"])
 ("c''" ["c'"])
 ("c,," ["c,"])
 ("c~~" ["c~"])
 ("d//" ["d/"])
 ("d~~" ["d~"])
 ("e''" ["e'"])
 ("e,," ["e,"])
 ("e\"\"" ["e\""])
 ("e~~" ["e~"])
 ("i''" ["i'"])
 ("i^^" ["i^"])
 ("l''" ["l'"])
 ("l//" ["l/"])
 ("l~~" ["l~"])
 ("n''" ["n'"])
 ("n~~" ["n~"])
 ("o''" ["o'"])
 ("o::" ["o:"])
 ("o\"\"" ["o\""])
 ("o^^" ["o^"])
 ("r''" ["r'"])
 ("r~~" ["r~"])
 ("s''" ["s'"])
 ("s,," ["s,"])
 ("s//" ["s/"])
 ("s~~" ["s~"])
 ("t,," ["t,"])
 ("t~~" ["t~"])
 ("u''" ["u'"])
 ("u.." ["u."])
 ("u::" ["u:"])
 ("u\"\"" ["u\""])
 ("y''" ["y'"])
 ("z''" ["z'"])
 ("z.." ["z."])
 ("z~~" ["z~"])
 )

;; Emacs can get confused with this file, so we help out
;; Local Variables:
;; coding: iso-2022-7bit-unix
;; End:
